@@ -389,9 +389,16 @@ ADD  `fixed_next_time` int(10) unsigned NOT NULL;");
 	@$db->updatequery("ALTER TABLE `receive` ADD `senttime` DATETIME NOT NULL");
 
 /*1.25 fixed bug of cron SMS and &$ in resend.php */
-	echo "update done! <a href=''  target=_top>Return</a>";
 /*1.25-t1 modify ussd timeout from 10 to 20s */
 /*1.25-t2 modify ussd timeout from 20 to 30s */
 /*1.25-t3 modify ussd timeout from 30 to 60s */
 /*1.26 change null to LOGOUT*/
+/*1.27-t1 fixed bug of EXPIRY*/
+/*1.27-t2 fixed bug of cron sms*/
+/*1.27 add json api*/
+	@$db->updatequery("ALTER TABLE `sends` ADD `sending_line` int(11) NOT NULL default '0'");
+	@$db->updatequery("ALTER TABLE `system` ADD `json_send_url` varchar(128) NOT NULL");
+	@$db->updatequery("ALTER TABLE `system` ADD `json_recv_url` varchar(128) NOT NULL");
+
+echo "update done! <a href=''  target=_top>Return</a>";
 ?>
